package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.MallCmsNotice;
import com.ruoyi.mall.domain.vo.IndexNoticeVO;

/**
 * 公告Service接口
 * 
 * @author chang
 * @date 2021-11-25
 */
public interface IMallCmsNoticeService 
{
    /**
     * 查询公告
     * 
     * @param id 公告主键
     * @return 公告
     */
    public MallCmsNotice selectMallCmsNoticeById(Long id);

    /**
     * 查询公告列表
     * 
     * @param mallCmsNotice 公告
     * @return 公告集合
     */
    public List<MallCmsNotice> selectMallCmsNoticeList(MallCmsNotice mallCmsNotice);

    /**
     * 新增公告
     * 
     * @param mallCmsNotice 公告
     * @return 结果
     */
    public int insertMallCmsNotice(MallCmsNotice mallCmsNotice);

    /**
     * 修改公告
     * 
     * @param mallCmsNotice 公告
     * @return 结果
     */
    public int updateMallCmsNotice(MallCmsNotice mallCmsNotice);

    /**
     * 批量删除公告
     * 
     * @param ids 需要删除的公告主键集合
     * @return 结果
     */
    public int deleteMallCmsNoticeByIds(Long[] ids);

    /**
     * 删除公告信息
     * 
     * @param id 公告主键
     * @return 结果
     */
    public int deleteMallCmsNoticeById(Long id);

    public List<IndexNoticeVO> indexSelectMallCmsNoticeList(MallCmsNotice mallCmsNotice);
}
