package com.ruoyi.mall.controller;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallCmsNotice;
import com.ruoyi.mall.service.IMallCmsNoticeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 公告Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallCmsNotice")
public class MallCmsNoticeController extends BaseController
{
    @Autowired
    private IMallCmsNoticeService mallCmsNoticeService;

    /**
     * 查询公告列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCmsNotice:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallCmsNotice mallCmsNotice)
    {
        startPage();
        List<MallCmsNotice> list = mallCmsNoticeService.selectMallCmsNoticeList(mallCmsNotice);
        return getDataTable(list);
    }

    /**
     * 导出公告列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCmsNotice:export')")
    @Log(title = "公告", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallCmsNotice mallCmsNotice)
    {
        List<MallCmsNotice> list = mallCmsNoticeService.selectMallCmsNoticeList(mallCmsNotice);
        ExcelUtil<MallCmsNotice> util = new ExcelUtil<MallCmsNotice>(MallCmsNotice.class);
        return util.exportExcel(list, "公告数据");
    }

    /**
     * 获取公告详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCmsNotice:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallCmsNoticeService.selectMallCmsNoticeById(id));
    }

    /**
     * 新增公告
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCmsNotice:add')")
    @Log(title = "公告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallCmsNotice mallCmsNotice)
    {
        mallCmsNotice.setCreateAt(DateUtils.getTime());
        return toAjax(mallCmsNoticeService.insertMallCmsNotice(mallCmsNotice));
    }

    /**
     * 修改公告
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCmsNotice:edit')")
    @Log(title = "公告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallCmsNotice mallCmsNotice)
    {
        return toAjax(mallCmsNoticeService.updateMallCmsNotice(mallCmsNotice));
    }

    /**
     * 删除公告
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCmsNotice:remove')")
    @Log(title = "公告", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallCmsNoticeService.deleteMallCmsNoticeByIds(ids));
    }
}
